==> vulkan4j-0.1.0-sources.jar: tech/icey/vk4j/datatype/VkSamplerReductionModeCreateInfo.java <==
package tech.icey.vk4j.datatype;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.enumtype;
import tech.icey.panama.annotation.nullable;
import tech.icey.panama.annotation.pointer;
import tech.icey.vk4j.enumtype.VkSamplerReductionMode;
import tech.icey.vk4j.enumtype.VkStructureType;

import java.lang.foreign.*;

import static java.lang.foreign.ValueLayout.OfInt;
import static java.lang.foreign.ValueLayout.PathElement;
import static tech.icey.vk4j.enumtype.VkStructureType.VK_STRUCTURE_TYPE_SAMPLER_REDUCTION_MODE_CREATE_INFO;

/// {@snippet lang=c :
/// typedef struct VkSamplerReductionModeCreateInfo {
///     VkStructureType sType;
///     const void* pNext;
///     VkSamplerReductionMode reductionMode;
/// } VkSamplerReductionModeCreateInfo;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkSamplerReductionModeCreateInfo.html">VkSamplerReductionModeCreateInfo</a>
public record VkSamplerReductionModeCreateInfo(MemorySegment segment) implements IPointer {
    public VkSamplerReductionModeCreateInfo(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_SAMPLER_REDUCTION_MODE_CREATE_INFO);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkSamplerReductionMode.class) int reductionMode() {
        return segment.get(LAYOUT$reductionMode, OFFSET$reductionMode);
    }

    public void reductionMode(@enumtype(VkSamplerReductionMode.class) int value) {
        segment.set(LAYOUT$reductionMode, OFFSET$reductionMode, value);
    }

    public static VkSamplerReductionModeCreateInfo allocate(Arena arena) {
        return new VkSamplerReductionModeCreateInfo(arena.allocate(LAYOUT));
    }

    public static VkSamplerReductionModeCreateInfo[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkSamplerReductionModeCreateInfo[] ret = new VkSamplerReductionModeCreateInfo[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkSamplerReductionModeCreateInfo(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkSamplerReductionModeCreateInfo clone(Arena arena, VkSamplerReductionModeCreateInfo src) {
        VkSamplerReductionModeCreateInfo ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkSamplerReductionModeCreateInfo[] clone(Arena arena, VkSamplerReductionModeCreateInfo[] src) {
        VkSamplerReductionModeCreateInfo[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("reductionMode")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$reductionMode = PathElement.groupElement("reductionMode");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$reductionMode = (OfInt) LAYOUT.select(PATH$reductionMode);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$reductionMode = LAYOUT.byteOffset(PATH$reductionMode);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$reductionMode = LAYOUT$reductionMode.byteSize();
}

==> vulkan4j-0.2.0-sources.jar: tech/icey/vk4j/datatype/VkSamplerReductionModeCreateInfo.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkSamplerReductionModeCreateInfo {
///     VkStructureType sType;
///     const void* pNext;
///     VkSamplerReductionMode reductionMode;
/// } VkSamplerReductionModeCreateInfo;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkSamplerReductionModeCreateInfo.html">VkSamplerReductionModeCreateInfo</a>
public record VkSamplerReductionModeCreateInfo(MemorySegment segment) implements IPointer {
    public VkSamplerReductionModeCreateInfo(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_SAMPLER_REDUCTION_MODE_CREATE_INFO);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkSamplerReductionMode.class) int reductionMode() {
        return segment.get(LAYOUT$reductionMode, OFFSET$reductionMode);
    }

    public void reductionMode(@enumtype(VkSamplerReductionMode.class) int value) {
        segment.set(LAYOUT$reductionMode, OFFSET$reductionMode, value);
    }

    public static VkSamplerReductionModeCreateInfo allocate(Arena arena) {
        return new VkSamplerReductionModeCreateInfo(arena.allocate(LAYOUT));
    }

    public static VkSamplerReductionModeCreateInfo[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkSamplerReductionModeCreateInfo[] ret = new VkSamplerReductionModeCreateInfo[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkSamplerReductionModeCreateInfo(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkSamplerReductionModeCreateInfo clone(Arena arena, VkSamplerReductionModeCreateInfo src) {
        VkSamplerReductionModeCreateInfo ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkSamplerReductionModeCreateInfo[] clone(Arena arena, VkSamplerReductionModeCreateInfo[] src) {
        VkSamplerReductionModeCreateInfo[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("reductionMode")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$reductionMode = PathElement.groupElement("reductionMode");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$reductionMode = (OfInt) LAYOUT.select(PATH$reductionMode);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$reductionMode = LAYOUT.byteOffset(PATH$reductionMode);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$reductionMode = LAYOUT$reductionMode.byteSize();
}
